@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.15 2004/07/18 23:25:25 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.16 2004/08/13 11:45:59 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -34,6 +34,7 @@
 #include <errno.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <signal.h>
 
@@ -475,13 +476,27 @@ static RETSIGTYPE exit_handler(int sig)
 {
 	int i;
 
+	/*
+	 * this could happend in a child process if a signal has been sent
+	 * before resetting signal handler
+	 */
+	if (getpid() != mypid)
+	{
+		pool_debug("exit_handler: I am not parent");
+		exit(0);
+	}
+
+	pool_debug("exit_handler called");
+
 	exiting = 1;
 
 	for (i = 0; i < pool_config.num_init_children; i++)
 	{
 		pid_t pid = pids[i];
 		if (pid)
+		{
 			kill(pid, SIGTERM);
+		}
 	}
 	while (wait(NULL) > 0)
 		;
@@ -503,6 +518,16 @@ static RETSIGTYPE failover_handler(int sig)
 
 	pool_debug("failover_handler called");
 
+	/*
+	 * this could happend in a child process if a signal has been sent
+	 * before resetting signal handler
+	 */
+	if (getpid() != mypid)
+	{
+		pool_debug("exit_handler: I am not parent");
+		return;
+	}
+
 	if (exiting)
 		return;
 
@@ -512,11 +537,6 @@ static RETSIGTYPE failover_handler(int sig)
 	/* secondary backend exists? */
 	if (pool_config.secondary_backend_port == 0)
 		return;
-#ifdef NOT_USED
-	/* in replication mode and already degeneration done */
-	else if (pool_config.replication_mode && !pool_config.replication_enabled)
-		return;
-#endif
 
 	/* already failover */
 	if (strcmp(pool_config.current_backend_host_name, pool_config.secondary_backend_host_name) ||
@@ -618,6 +638,8 @@ static RETSIGTYPE reap_handler(int sig)
 		{
 #endif
 
+			pool_debug("child %d exits with signal %d", pid, WTERMSIG(status));
+
 			/* look for exiting child's pid */
 			for (i=0;i<pool_config.num_init_children;i++)
 			{
