@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_auth.c,v 1.13 2004/07/19 01:28:44 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_auth.c,v 1.14 2004/08/13 11:47:51 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -47,7 +47,7 @@ static int do_md5(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reaut
 int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 {
 	int status;
-	char kind;
+	signed char kind;
 	int pid, pid1;
 	int key, key1;
 	int protoMajor;
@@ -883,7 +883,7 @@ int pool_read_message_length(POOL_CONNECTION_POOL *cp)
 	return length;
 }
 
-char pool_read_kind(POOL_CONNECTION_POOL *cp)
+signed char pool_read_kind(POOL_CONNECTION_POOL *cp)
 {
 	int status;
 	char kind, kind1;
