@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.28 2004/07/22 10:37:06 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.29 2004/08/13 11:47:51 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -508,7 +508,7 @@ static POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 		if (MAJOR(backend) == PROTO_MAJOR_V3)
 		{
 			int len;
-			char state;
+			signed char state;
 
 			if ((len = pool_read_message_length(backend)) < 0)
 				return POOL_END;
@@ -1050,7 +1050,7 @@ static POOL_STATUS CopyDataRows(POOL_CONNECTION *frontend,
 			/* CopyOut */
 			if (MAJOR(backend) == PROTO_MAJOR_V3)
 			{
-				char kind;
+				signed char kind;
 
 				if ((kind = pool_read_kind(backend)) < 0)
 					return POOL_END;
